@@ -1,3 +1,4 @@
+#' @export
 freqs<-function(pp)
 {
 	m<-union(pp$marks,NULL)
@@ -7,6 +8,7 @@ freqs<-function(pp)
 	h
 }
 ####################################################################################
+#' @export
 clean.up.data<-function(pp,dbh=10,atleast=10)
 {
 	h<-freqs(pp)
@@ -20,8 +22,9 @@ clean.up.data<-function(pp,dbh=10,atleast=10)
         p$marks<-factor(marks)
 	p
 }
-
 ####################################################################################
+#' @import stats
+#' @export
 shake<-function(pp, a=0.001)
 {
 	pp$x<-pp$x+runif(pp$n, -a,a)
@@ -29,7 +32,8 @@ shake<-function(pp, a=0.001)
 	pp
 }
 ####################################################################################
-minusID<-function(pp, minusR, dbh, atleast=0)#, lifeform, status)
+#' @export
+minusID<-function(pp, minusR, dbh, atleast=0)
 {
 	id<-( pp$x<(pp$window$x[2]-minusR) ) & (pp$x>(pp$window$x[1]+minusR)) & (pp$y<(pp$window$y[2]-minusR)) & (pp$y>(pp$window$y[1]+minusR)) 
 	if(!is.null(pp$dbh) & !missing(dbh))
@@ -45,18 +49,6 @@ minusID<-function(pp, minusR, dbh, atleast=0)#, lifeform, status)
 				id[bad]<- FALSE
 		}
 	}
-#	if(!missing(lifeform))
-#	{
-#		sp<-levels(pp$marks)
-#		lfs<-bcispecies.lifeform(lifeform=lifeform)
-#		bad<-sp[!(sp%in%lfs)]
-#		for(s in bad)
-#			id[pp$marks==s]<-FALSE
-#	}
-#	if(!missing(status))
-#	{
-#		id[!(pp$status%in%status)]<-FALSE
-#	}
 	if(sum(is.na(id))>0) warning("Vector contains NA's.")
 	id
 }
